@@ -9,6 +9,8 @@
 test.all <- function() {
     test <- new(TestBytes, req = "abc", rep = list(charToRaw("def"), raw(10)))
     checkEquals(rawToChar(test$req), "abc")
+    test$req <- charToRaw("abc")
+    checkEquals(rawToChar(test$req), "abc")
     checkEquals(rawToChar(test$opt), "hello world")
     checkEquals(test$rep, list(charToRaw("def"), raw(10)))
     test$rep[[3]]=charToRaw("ghi")
@@ -18,4 +20,9 @@ test.all <- function() {
     checkEquals(rawToChar(test1$req), "abc")
     checkEquals(rawToChar(test1$opt), "hello world")
     checkEquals(test1$rep, list(charToRaw("def"), raw(10), charToRaw("ghi")))
+
+    # Test raw(10) can be set to a single req field.
+    test$req <- raw(10)
+    checkEquals(length(test$req), 10)
+    checkTrue(all(test$req == raw(10)))
 }
